====================
Plugins
====================

lunchable supports plugins with other, external, services.
See below for what's been built already. If you can't find what you're
looking for, consider building it yourself and opening a pull-request.

.. toctree::
   :maxdepth: 1

   pushlunch.rst
   splitlunch.rst
   primelunch.rst
